# xrpl-nocode-automation
This repository contains code which allows users to run automated XRPL tests on different networks. It also generates a python package named 'claudia', which can be installed from [PyPi](https://pypi.org/project/claudia/).

---

## Claudia
Please read more about Claudia [here](src/claudia/README.md).
